@@ -68,7 +68,7 @@ cat_delta <- function(x, y = NULL, method = NULL, method_cat="tot_var_dist", mkw
   }else{
     
     
-    crs = crossing(a=1:(nvar),b=1:nvar) %>% filter(a!=b)
+    crs = tidyr::crossing(a=1:(nvar),b=1:nvar) %>% dplyr::filter(a!=b)
     blocks_id_a = level_pos[crs$a,]
     blocks_id_b = level_pos[crs$b,] %>% rename(`end_start`=start,`end_stop`=stop)
     block_ids=cbind(blocks_id_a,blocks_id_b)
